 /* $Id: hook.h,v 1.7 2000/07/17 17:04:17 edwards Exp $ */
 
/*
 * hook.h: header for hook.c
 * 
 * Copyright 1990, 1995 Michael Sandrof, Matthew Green and others
 * Copyright 1997 EPIC Software Labs
 * See the COPYRIGHT file for license information.
 */

#ifndef __hook_h__
#define __hook_h__

enum HOOK_TYPES {
	ACTION_LIST,
	BROWSE_BEGIN_LIST,
	BROWSE_END_LIST,
	CHANNEL_JOIN_LIST,
	CONNECT_LIST,
	DISCONNECT_LIST,
	ERROR_LIST,
	EXEC_LIST,
	EXEC_ERRORS_LIST,
	EXEC_EXIT_LIST,
	EXEC_PROMPT_LIST,
	EXIT_LIST,
	FLOOD_LIST,
	HELPWIN_LIST,
	HOOK_LIST,
	HOTLIST_LIST,
	IDLE_LIST,
	INPUT_LIST,
	JOIN_LIST,
	KILL_LIST,
	LEAVE_LIST,
	LIST_LIST,
	MP3_LIST,
	MSG_LIST,
	NAMES_LIST,
	NAP_LIST,
	NAPERROR_LIST,
	NAPFINISH_LIST,
	NAPGET_LIST,
	NAPREQUEST_LIST,
	NAPSEND_LIST,
	PASTE_LIST,
	PONG_LIST,
	PUBLIC_LIST,
	PUBLIC_OTHER_LIST,
	RAW_IRC_LIST,
	SEARCH_BEGIN_LIST,
	SEARCH_END_LIST,
	SEND_ACTION_LIST,
	SEND_MSG_LIST,
	SEND_OPS_LIST,
	SEND_PUBLIC_LIST,
	SERVERMSG_LIST,
	SIGUSR1_LIST,
	STATUS_UPDATE_LIST,
	SWITCH_CHANNELS_LIST,
	SWITCH_WINDOWS_LIST,
	TIMER_LIST,
	TIMER_HOUR_LIST,
	TOPIC_LIST,
	WALL_LIST,
	WHO_LIST,
	WINDOW_LIST,
	WINDOW_CREATE_LIST,
	WINDOW_KILL_LIST,
	ZZZZ_THIS_ALWAYS_COMES_LAST_ZZZZ
};

#define NUMBER_OF_LISTS ZZZZ_THIS_ALWAYS_COMES_LAST_ZZZZ

	BUILT_IN_COMMAND(oncmd);
	int	do_hook 		(int, char *, ...);
	void	flush_on_hooks 		(void);
	void	unload_on_hooks		(char *);
	void	save_hooks 		(FILE *, int);

#endif /* __hook_h_ */
